#
# 1901.07024.R,  3 Jul 19
# Data from:
# Temporal Discounting in Technical Debt: How do Software Practitioners Discount the Future?
# Christoph Becker and Fabian Fagerholm and Rahul Mohanani and Alexander Chatzigeorgiou
#
# Example from:
# Evidence-based Software Engineering: based on the publicly available data
# Derek M. Jones
#
# TAG

source("ESEUR_config.r")


library("lme4")
library("reshape2")


plot_indiv=function(df, indiv)
{
sA=subset(df, individual == indiv)

plot(sA$years, sA$discount, type="b", log="y", col=point_col,
	xlab="Years", ylab="Discount\n")

text(8, max(sA$discount*0.9), indiv, cex=1.6)
}


c12=read.csv(paste0(ESEUR_dir, "developers/1901.07024.csv"), as.is=TRUE)

c12l=melt(c12, id.vars=c("Company", "individual", "Present.Value"),
		measure.vars=c("Y1", "Y2", "Y3", "Y4", "Y5", "Y10"))
c12l$variable=as.character(c12l$variable) # handle factor nonsense

c12l$years=as.integer(mapvalues(c12l$variable, 
                		c("Y1", "Y2", "Y3", "Y4", "Y5", "Y10"),
				c(1:5, 10)))
c12l$discount=c12l$Present.Value/c12l$value


c1=subset(c12l, Company == "C1")
c2=subset(c12l, Company == "C2")

plot_layout(2, 3)

plot_indiv(c1, "A")
plot_indiv(c1, "B")
plot_indiv(c1, "C")
plot_indiv(c1, "E")
plot_indiv(c1, "G")
plot_indiv(c1, "M")

exp_mod=glm(log(discount) ~ individual*years, data=c1)
summary(exp_mod)

hyp_mod=glm(discount ~ individual+I(1/(1+years)), data=c2)
summary(hyp_mod)

# Not quiet as good as a model that includes individuals
# dis_mod=nls(discount ~ a+1/(1+b*years), data=c1,
# 		start=list(a=0.26, b=0.9), trace=TRUE)


sdis_mod=lmer(discount ~ I(1/(1+years))+(years | individual), data=c1)
summary(sdis_mod)


